==> apache-trafficcontrol-7.0.1.tar.gz: apache-trafficcontrol-7.0.1/traffic_ops/v4-client/traffic_monitor.go <==
package client

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import (
	"fmt"
	"net/url"

	"github.com/apache/trafficcontrol/lib/go-tc"
	"github.com/apache/trafficcontrol/traffic_ops/toclientlib"
)

// apiCDNMonitoringConfig is the API path on which Traffic Ops serves the CDN monitoring
// configuration information. It is meant to be used with fmt.Sprintf to insert the necessary
// path parameters (namely the Name of the CDN of interest).
// See Also: https://traffic-control-cdn.readthedocs.io/en/latest/api/v3/cdns_name_configs_monitoring.html
const apiCDNMonitoringConfig = "/cdns/%s/configs/monitoring"

// GetTrafficMonitorConfig returns the monitoring configuration for the CDN named by 'cdn'.
func (to *Session) GetTrafficMonitorConfig(cdn string, opts RequestOptions) (tc.TMConfigResponse, toclientlib.ReqInf, error) {
	route := fmt.Sprintf(apiCDNMonitoringConfig, url.PathEscape(cdn))
	var data tc.TMConfigResponse
	reqInf, err := to.get(route, opts, &data)
	return data, reqInf, err
}

==> apache-trafficcontrol-8.0.2.tar.gz: apache-trafficcontrol-8.0.2/traffic_ops/v4-client/traffic_monitor.go <==
package client

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import (
	"fmt"
	"net/url"

	"github.com/apache/trafficcontrol/v8/lib/go-tc"
	"github.com/apache/trafficcontrol/v8/traffic_ops/toclientlib"
)

// apiCDNMonitoringConfig is the API path on which Traffic Ops serves the CDN monitoring
// configuration information. It is meant to be used with fmt.Sprintf to insert the necessary
// path parameters (namely the Name of the CDN of interest).
// See Also: https://traffic-control-cdn.readthedocs.io/en/latest/api/v3/cdns_name_configs_monitoring.html
const apiCDNMonitoringConfig = "/cdns/%s/configs/monitoring"

// GetTrafficMonitorConfig returns the monitoring configuration for the CDN named by 'cdn'.
func (to *Session) GetTrafficMonitorConfig(cdn string, opts RequestOptions) (tc.TMConfigResponse, toclientlib.ReqInf, error) {
	route := fmt.Sprintf(apiCDNMonitoringConfig, url.PathEscape(cdn))
	var data tc.TMConfigResponse
	reqInf, err := to.get(route, opts, &data)
	return data, reqInf, err
}
